package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Nov 14, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Bind struct {
Tag string `toml:"tag"`
Local string `toml:"local"`
Remote string `toml:"remote"`
}
type Conf struct {
Jump string `toml:"jump"`
Key string `toml:"key"`
Passphrase string `toml:"passphrase"`
Binds []*Bind `toml:"binds"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.